"""Tests for the test runner."""

import os
import shutil

from ubuntuone.devtools.testcases.dbus import DBusTestCase
from ubuntuone.devtools.services.dbus import DBusRunner
from urllib import unquote


class TestWithDBus(DBusTestCase):
    """Test that the DBus runner works correctly."""

    def test_dbus_session_is_running(self):
        """Test that dbus session is the private one we started."""
        bus_address = os.environ.get('DBUS_SESSION_BUS_ADDRESS', None)
        self.assertEqual(os.path.dirname(
                unquote(bus_address.split(',')[0].split('=')[1])),
                         os.path.dirname(os.getcwd()))

    def test_config_file_path(self):
        """Test that we loaded the config file from the local tree."""
        expected = os.path.abspath(os.path.join(
                self.tmpdir, 'dbus-session.conf'))
        runner = DBusRunner()
        # pylint: disable=W0212
        os.makedirs(self.tmpdir)
        runner._generate_config_file(tempdir=self.tmpdir)
        shutil.rmtree(self.tmpdir)
        self.assertEqual(expected, runner.config_file)
